@@ -6,7 +6,6 @@ from decimal import Decimal
 from io import BytesIO, StringIO
 from os.path import join
 from urllib.parse import urlparse
-
 from django.core.management import call_command
 from django.utils import timezone
 from typing import List
@@ -75,7 +74,7 @@ from jutil.format import (
     dec5,
     dec6,
     format_table,
-    ucfirst_lazy,
+    capfirst_lazy,
     strip_media_root,
     get_media_full_path,
     camel_case_to_underscore,
@@ -84,6 +83,7 @@ from jutil.format import (
     format_dict_as_html,
     choices_label,
     is_media_full_path,
+    capfirst_lazy,
 )
 from jutil.parse import parse_datetime, parse_bool, parse_datetime_or_none
 from jutil.validators import (
@@ -126,6 +126,7 @@ from jutil.validators import (
     iban_generator,
     bic_sanitizer,
     filter_country_company_org_id,
+    variable_name_sanitizer,
 )
 from xml.etree.ElementTree import Element
 from xml.etree import ElementTree as ET
@@ -577,9 +578,7 @@ class Tests(TestCase, TestSetupMixin):
         ]
         day_ranges = [7, 15, 30, 60, 90]
         for days in day_ranges:
-            named_ranges.append(
-                ("plus_minus_{}d".format(days), (t_tz - timedelta(days=days), t_tz + timedelta(days=days)))
-            )
+            named_ranges.append(("plus_minus_{}d".format(days), (t_tz - timedelta(days=days), t_tz + timedelta(days=days))))
             named_ranges.append(("prev_{}d".format(days), (t_tz - timedelta(days=days), t_tz)))
             named_ranges.append(("next_{}d".format(days), (t_tz, t_tz + timedelta(days=days))))
         for name, res in named_ranges:
@@ -709,9 +708,7 @@ class Tests(TestCase, TestSetupMixin):
             self.assertEqual(
                 fi_ssn_age(ssn, date_now),
                 age,
-                msg="{} age is {} on {} but fi_ssn_age result was {}".format(
-                    ssn, age, date_now, fi_ssn_age(ssn, date_now)
-                ),
+                msg="{} age is {} on {} but fi_ssn_age result was {}".format(ssn, age, date_now, fi_ssn_age(ssn, date_now)),
             )
 
     def test_se_banks(self):
@@ -941,8 +938,8 @@ class Tests(TestCase, TestSetupMixin):
             """.strip()
         self.assertEqual(out, out_ref)
 
-    def test_ucfirst_lazy(self):
-        s = gettext_lazy(ucfirst_lazy("missing value"))
+    def test_capfirst_lazy(self):
+        s = gettext_lazy(capfirst_lazy("missing value"))
         s_ref = gettext_lazy("Missing value")
         s_en = "Missing value"
         s_fi = "Puuttuva arvo"
@@ -1009,14 +1006,10 @@ class Tests(TestCase, TestSetupMixin):
                     iban_validator(acc)
                 except Exception as e:
                     print("iban_generator() returned", acc, "but iban_validator() raised exception", e)
-                    self.fail(
-                        "iban_validator(iban_generator()) should not raise Exception, account number was {}".format(acc)
-                    )
+                    self.fail("iban_validator(iban_generator()) should not raise Exception, account number was {}".format(acc))
         with self.assertRaisesMessage(ValidationError, _("Invalid country code")):
             iban_generator("XX")
-        with self.assertRaisesMessage(
-            ValidationError, _("IBAN checksum generation does not support >26 character IBANs")
-        ):
+        with self.assertRaisesMessage(ValidationError, _("IBAN checksum generation does not support >26 character IBANs")):
             iban_generator("AL")
 
     def test_make_email_recipient(self):
@@ -1147,9 +1140,7 @@ class Tests(TestCase, TestSetupMixin):
             self.assertIn("django_language", request.COOKIES)
             self.assertIn(request.COOKIES["django_language"], lang_code)
             self.assertIn("django_language", res.cookies)
-            self.assertEqual(
-                str(res.cookies["django_language"]), "Set-Cookie: django_language={}; Path=/".format(lang_code)
-            )
+            self.assertEqual(str(res.cookies["django_language"]), "Set-Cookie: django_language={}; Path=/".format(lang_code))
 
         # ActivateUserProfileTimezoneMiddleware
         user = self.user
@@ -1269,6 +1260,16 @@ class Tests(TestCase, TestSetupMixin):
             data = json.loads(out.getvalue())
             self.assertListEqual(data_ref, data)
 
+    def test_filters(self):
+        vals = [
+            (
+                "24: REGISTRO COMPLEMENTARIO DE INFORMACIÓN DE EQUIVALENCIA DE IMPORTE DEL APUNTE (OPCIONAL)",
+                "_24_REGISTRO_COMPLEMENTARIO_DE_INFORMACION_DE_EQUIVALENCIA_DE_IMPORTE_DEL_APUNTE_OPCIONAL",
+            ),
+        ]
+        for src, dst in vals:
+            self.assertEqual(variable_name_sanitizer(src), dst)
+
     def test_find_file(self):
         dir_name = os.path.join(settings.BASE_DIR, "jutil/locale")
         cases = [
